Learn R Programming

mgarchBEKK (version 0.0.1)

BEKK: Provide the MGARCH-BEKK estimation procedure.

Description

Provide the MGARCH-BEKK estimation procedure.

Usage

BEKK(eps, order = c(1, 1), params = NULL, fixed = NULL, method = "BFGS",
  verbose = F)

Arguments

eps
Data frame holding time series.
order
BEKK(p, q) order
params
Initial parameters for the optim function.
fixed
Vector of parameters to be fixed.
method
The method that will be used by the optim function.
verbose
Indicates if we need verbose output during the estimation.

Value

  • Estimation results packaged as BEKK class instance.

Examples

Run this code
## Simulate series:
simulated <- simulateBEKK(2, 1000, c(1,1))

## Prepare the matrix:
simulated <- do.call(cbind, simulated$eps)

## Estimate with default arguments:
estimated <- BEKK(simulated)

## Show diagnostics:
diagnoseBEKK(estimated)

Run the code above in your browser using DataLab