Learn R Programming

mgarchBEKK (version 0.0.1)

diagnoseBEKK: Provides diagnostics for a BEKK process estimation.

Description

This procedure provides console output and browsable plots for a given BEKK process estimation. Therefore, it is meant to be interactive as the user needs to proceed by pressing c on the keyboard to see each plot one-by-one.

Usage

diagnoseBEKK(estimation)

Arguments

estimation
The return value of the mvBEKK.est function

Value

  • Nothing

Examples

Run this code
## Simulate series:
simulated = simulateBEKK(2, 1000, c(1,1))

## Prepare the matrix:
simulated = do.call(cbind, simulated$eps)

## Estimate with default arguments:
estimated = BEKK(simulated)

## Show diagnostics:
diagnoseBEKK(estimated)

Run the code above in your browser using DataLab